@@ -3,9 +3,9 @@
 
 #include <QtCore>
 #include <mbarcode-qt/plugininterfaces.h>
-#include <mbarcode-qt/sinkplugin.h>
+#include <mbarcode-qt/pluginaction.h>
 class Plugin;
-class GiveOpinionSink : public QObject, public SinkPlugin
+class GiveOpinionSink : public QObject, public PluginAction
 {
     Q_OBJECT
 
@@ -13,13 +13,15 @@ public:
     // inherited virtuals
     GiveOpinionSink(const PluginInterface *interface);
 
-    QString getName() {return "Informed Individual Give Opinion Sink Plugin";};
+    QString getName() {return "Informed Individual Give Opinion Sink Plugin";}
     QString getText() {return "Give Opinion with Informed Individual"; }
-    bool isReady() {return true;};
+    QImage getImage();
+    bool isReady() {return true;}
     void clickAction(QWidget *parentWindow);
     void setPlugin(Plugin *plugin);
 private:
     Plugin *plugin;
+    QImage image;
 };
 
 #endif // GIVEOPINIONSINK_H
